@@ -262,7 +262,7 @@ func (c *MachineConfig) Stop() error {
 			return nil
 		} else {
 			//pidFile := filepath.Join(c.Location, "alpine.pid")
-			return errors.New("failed to stop instance `" + c.Alias + "` due to inadequate preiveledges")
+			return errors.New("failed to stop instance `" + c.Alias + "` due to inadequate privileges")
 		}
 	}
 	return nil
@@ -364,6 +364,15 @@ func (c *MachineConfig) Start() error {
 
 	if c.VMNet {
 		networkDevice = "vmnet-shared,id=net0"
+
+		if c.MACAddress == "" {
+			macAddress, err := utils.GenerateMACAddress()
+			if err != nil {
+				log.Fatal(err)
+			}
+
+			c.MACAddress = macAddress
+		}
 	}
 
 	// Only parse ports of using qemu's default slirp network
@@ -503,7 +512,29 @@ func (c *MachineConfig) Start() error {
 		return errors.New("unable to start instance")
 	}
 
+	err = c.Exec("hwclock -s", true)
+	if err != nil {
+		c.Stop()
+		c.CleanPIDFile()
+		return err
+	}
+
+	config, err := yaml.Marshal(&c)
+	if err != nil {
+		c.Stop()
+		c.CleanPIDFile()
+		return err
+	}
+
+	err = os.WriteFile(filepath.Join(c.Location, "config.yaml"), config, 0644)
+	if err != nil {
+		c.Stop()
+		c.CleanPIDFile()
+		return err
+	}
+
 	log.Println(c.Alias + " started (" + strconv.Itoa(pid) + ")")
+
 	return nil
 }
 
