@@ -5,12 +5,14 @@ reboot
 # ssh back into the vm
 /sbin/modprobe zfs
 
-echo "http://dl-cdn.alpinelinux.org/alpine/edge/main" > /etc/apk/repositories
-echo "http://dl-cdn.alpinelinux.org/alpine/edge/community" >> /etc/apk/repositories
-echo "http://dl-cdn.alpinelinux.org/alpine/edge/testing" >> /etc/apk/repositories
+#echo "http://dl-cdn.alpinelinux.org/alpine/edge/main" > /etc/apk/repositories
+#echo "http://dl-cdn.alpinelinux.org/alpine/edge/community" >> /etc/apk/repositories
+#echo "http://dl-cdn.alpinelinux.org/alpine/edge/testing" >> /etc/apk/repositories
+
+echo "http://dl-cdn.alpinelinux.org/alpine/v3.16/community" >> /etc/apk/repositories
 
 apk update
-apk upgrade
+#apk upgrade
 
 apk add --no-cache lxd lxd-client dbus
 
